@@ -1,7 +1,7 @@
 #ifndef _BITLBEE_H
 #define _BITLBEE_H
 
-#define BITLBEE_VERSION "0.72"
+#define BITLBEE_VERSION "0.74a"
 
 #include "config.h"
 
@@ -29,7 +29,7 @@
 #define ROOT_NICK "root"
 #define ROOT_FN "User manager"
 #define DEFAULT_AWAY "Away from computer"
-#define CONTROL_TOPIC "Welcome to the control channel. Type help for help information."
+#define CONTROL_TOPIC "Welcome to the control channel. Type help for help information."
 #define IRCD_INFO "BitlBee <http://www.lintux.cx/bitlbee.html>"
 
 #define MAX_NICK_LENGTH 12
@@ -44,7 +44,7 @@
 int root_command_string( irc_t *irc, user_t *u, char *command );
 int root_command( irc_t *irc, char *command[] );
 int bitlbee_init( irc_t *irc );
-int bitlbee_load( irc_t *irc, char *password );	/* TODO Get rid of password arg? */
+int bitlbee_load( irc_t *irc, char *password );
 int bitlbee_save( irc_t *irc );
 void http_encode( char *s );
 void http_decode( char *s );
